import React, { useState } from 'react';
import Grid from '@mui/material/Grid'; // Using Grid (deprecated but configurable)
import ShipmentPanel from '../components/ShipmentPanel';
import ShipmentDetails from '../components/ShipmentDetails';
import ShipmentForm from '../components/ShipmentForm';
import { Dewar, Shipment_Input } from '../../openapi';

type ShipmentViewProps = React.PropsWithChildren<Record<string, never>>;

const ShipmentView: React.FC<ShipmentViewProps> = () => {
    const [isCreatingShipment, setIsCreatingShipment] = useState(false);
    const [selectedShipment, setSelectedShipment] = useState<Shipment_Input | null>(null);
    const [selectedDewar, setSelectedDewar] = useState<Dewar | null>(null);

    const handleSelectShipment = (shipment: Shipment_Input | null) => {
        setSelectedShipment(shipment);
        setIsCreatingShipment(false);
    };

    const handleCancelShipmentForm = () => {
        setIsCreatingShipment(false);
    };

    const renderShipmentContent = () => {
        if (isCreatingShipment) {
            return <ShipmentForm sx={{ flexGrow: 1 }} onCancel={handleCancelShipmentForm} />;
        }
        if (selectedShipment) {
            return (
                <ShipmentDetails
                    isCreatingShipment={isCreatingShipment}
                    sx={{ flexGrow: 1 }}
                    selectedShipment={selectedShipment}
                    selectedDewar={selectedDewar}
                    setSelectedDewar={setSelectedDewar}
                />
            );
        }
        return <div>No shipment details available.</div>;
    };

    return (
        <Grid container spacing={2} sx={{ height: '100vh' }}>
            <Grid
                item
                xs={12}
                md={3}
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 0,
                }}
            >
                <ShipmentPanel
                    selectedPage="Shipments"
                    setCreatingShipment={setIsCreatingShipment}
                    selectShipment={handleSelectShipment}
                />
            </Grid>
            <Grid
                item
                xs={12}
                md={8}
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    flexGrow: 1,
                }}
            >
                {renderShipmentContent()}
            </Grid>
        </Grid>
    );
};

export default ShipmentView;